package com.zhyc.module.biosafety.mapper;

import java.util.List;

import com.zhyc.module.biosafety.domain.QuarantineItems;
import org.apache.ibatis.annotations.Mapper;

/**
 * 检疫项目Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-14
 */
@Mapper
public interface QuarantineItemsMapper 
{
    /**
     * 查询检疫项目
     * 
     * @param id 检疫项目主键
     * @return 检疫项目
     */
    public QuarantineItems selectQuarantineItemsById(Long id);

    /**
     * 查询检疫项目列表
     * 
     * @param quarantineItems 检疫项目
     * @return 检疫项目集合
     */
    public List<QuarantineItems> selectQuarantineItemsList(QuarantineItems quarantineItems);

    /**
     * 新增检疫项目
     * 
     * @param quarantineItems 检疫项目
     * @return 结果
     */
    public int insertQuarantineItems(QuarantineItems quarantineItems);

    /**
     * 修改检疫项目
     * 
     * @param quarantineItems 检疫项目
     * @return 结果
     */
    public int updateQuarantineItems(QuarantineItems quarantineItems);

    /**
     * 删除检疫项目
     * 
     * @param id 检疫项目主键
     * @return 结果
     */
    public int deleteQuarantineItemsById(Long id);

    /**
     * 批量删除检疫项目
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQuarantineItemsByIds(Long[] ids);
}
